import { ConfigService } from '@nestjs/config';
import { Test, TestingModule } from '@nestjs/testing';
import { DefaultParamsProvider } from '../../../../adapters/secondaries/default-params.provider';
import { DefaultParams } from '../../../../domain/types/default-params.type';

const mockConfigService = {
  get: jest.fn().mockImplementation(() => 'some_default_value'),
};

describe('DefaultParamsProvider', () => {
  let defaultParamsProvider: DefaultParamsProvider;

  beforeAll(async () => {
    const module: TestingModule = await Test.createTestingModule({
      imports: [],
      providers: [
        DefaultParamsProvider,
        {
          provide: ConfigService,
          useValue: mockConfigService,
        },
      ],
    }).compile();

    defaultParamsProvider = module.get<DefaultParamsProvider>(
      DefaultParamsProvider,
    );
  });

  it('should be defined', () => {
    expect(defaultParamsProvider).toBeDefined();
  });

  it('should provide default params', async () => {
    const params: DefaultParams = defaultParamsProvider.getParams();
    expect(params.SUN_MARGIN).toBe('some_default_value');
    expect(params.PASSENGER).toBe(false);
    expect(params.DRIVER).toBe(false);
  });
});
